.. _bibliography:

Bibliography
============

.. _Gil76:

Daniel Gillespie. A general method for numerically simulating the
stochastic time evolution of coupled chemical reactions. Journal of
Computational Physics **22**, pp.403-–434. 1976.

.. _Gil77:

Daniel Gillespie. Exact stochastic simulation of coupled chemical
reactions. Journal of Physical Chemistry **81** (25),
pp.2340-–2361. 1977.

.. _Het00:

Herbert Hethcote. `The mathematics of infectious diseases
<http://dx.doi.org//10.1137/S0036144500371907>`_. SIAM Review **42**
(4), pp.599--653. December 2000.

.. _KMcK27:

W.O. Kermack and A.G. McKendrick. `A contribution to the mathematical
theory of epidemics
<http://dx.doi.org/10.1098/rspa.1927.0118>`_. Proceedings of the Royal
Society A **115** (772). 1927.

Istvan Kiss, Joel Miller, and Peter Simon. `Mathematics of
epidemics on networks <http://dx.doi.org/10.1007/978-3-319-50806-1>`_.
Springer series on Interdisciplinary Applied Mathematics
**46**. ISBN 978-3-319-50804-7. 2017.

.. _New02:
M.E.J. Newman. `Spread of epidemic disease on networks
<http://dx.doi.org/10.1103/PhysRevE.66.016128>`_. Physical Review E
**66**. July 2002.
